@@ -1,5 +1,21 @@
 #include "generator.ih"
 
+namespace 
+{
+    char const endPolyTypeAssign[] =
+R"(inline SType &SType::operator=(EndPolyType_ const &value)
+{
+    assign< Tag_::END_TAG_ >(value);
+    return *this;
+}
+inline SType &SType::operator=(EndPolyType_ &&tmp)
+{
+    assign< Tag_::END_TAG_ >(std::move(tmp));
+    return *this;
+}
+)";
+
+}
 void Generator::polymorphicOpAssignImpl(ostream &out) const
 {
     key(out);
@@ -17,6 +33,8 @@ void Generator::polymorphicOpAssignImpl(ostream &out) const
             "    assign< Tag_::" << poly.first << " >(std::move(tmp));\n"
             "    return *this;\n"
             "}\n";
+
+    out << endPolyTypeAssign;
 }
 
 
