@@ -4,13 +4,12 @@ void Generator::polymorphicSpecializations(ostream &out) const
 {
     key(out);
 
-    out <<
-        "enum { sizeofTag_ = " << d_polymorphic.size() << " };\n\n";
-
+    out.put('\n');
     if (d_options.tagMismatches().value == Options::ON)
-        out << "extern char const *idOfTag_[];\n";
+        out << "extern char const *idOfTag_[];\n";      // cf. idoftag.cc
 
     for (auto &poly: d_polymorphic)
+    {
         out << 
             "template <>\n"
             "struct TagOf<" << poly.second << ">\n"
@@ -18,8 +17,18 @@ void Generator::polymorphicSpecializations(ostream &out) const
             "    static Tag_ const tag = Tag_::" << poly.first << ";\n"
             "};\n"
             "\n";
+    }
+
+    out <<
+        "template <>\n"
+        "struct TagOf<EndPolyType_>\n"
+        "{\n"
+        "    static Tag_ const tag = Tag_::END_TAG_;\n"
+        "};\n"
+        "\n";
 
     for (auto &poly: d_polymorphic)
+    {
         out << 
             "template <>\n"
             "struct TypeOf<Tag_::" << poly.first << ">\n"
@@ -27,13 +36,13 @@ void Generator::polymorphicSpecializations(ostream &out) const
             "    using type = " << poly.second << ";\n"
             "};\n"
             "\n";
+    }
+
+    out <<
+        "template <>\n"
+        "struct TypeOf<Tag_::END_TAG_>\n"
+        "{\n"
+        "    using type = EndPolyType_;\n"
+        "};\n"
+        "\n";
 }
-
-
-
-
-
-
-
-
-
