@@ -5,7 +5,7 @@
 void Options::setPolymorphicDecl()
 {
     if (isFirstStypeDefinition())
-        d_stackDecl = "    typedef Meta_::SType STYPE_;\n";
+        d_stackDecl = "    using STYPE_ = Meta_::SType;\n";
 
     d_polymorphic = true;
 }
