@@ -4,7 +4,7 @@ void Parser::installDefaultAction(Production const &prod,
                                   string const &rhs)
 {
     Block block;
-    block.open(prod.lineNr(), prod.fileName());
+    block.open(prod.lineNr() - 1, prod.fileName());
 
     block += "\n"
         "    " + s_semanticValue + " = " + 
