@@ -14,7 +14,7 @@ bool Parser::svsPolyReplace(int nElements, Block &block,AtDollar const &atd,
                     tag.empty() ? 
                         ""s 
                     : 
-                        ".get<Tag__::" + tag + ">()"
+                        ".get<Tag_::" + tag + ">()"
                 ) + suffix);
 
     return false;
